@@ -5,7 +5,9 @@ from .enum_argparse import *
 from .file import *
 from .folder import *
 from .list_extension import *
+from .sftp import *
 
 __path__ = extend_path(__path__, "functional")
+__path__ = extend_path(__path__, "dl")
 
-__version__ = "0.1.3"
+__version__ = "0.1.4"
